/*
 * $RCSfile: NativeEnvironment.cc,v $
 * $Revision: 1.11 $
 *
 * Comments:
 *
 * (C) Copyright ParaSoft Corporation 1996.  All rights reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF ParaSoft
 * The copyright notice above does not evidence any
 * actual or intended publication of such source code.
 *
 * $Author: franczak $          $Locker:  $
 * $Date: 2008-03-26 13:08:20 $
 * $Log: not supported by cvs2svn $
 * Revision 1.10  2007/10/15 13:31:49  dario
 * Fixing problems with environment variables encoding: PR68917
 *
 * Revision 1.9  2006/11/14 13:32:30  dario
 * PR59086
 *
 * Revision 1.8  2006/02/10 14:06:14  dario
 * envenv fixed: see PR51080
 *
 * Revision 1.7  2005/11/21 11:45:51  dario
 * temporary changes in getenv reverted.
 *
 * Revision 1.6  2005/11/21 11:38:17  dario
 * added environment method
 *
 * Revision 1.5  2005/11/17 10:29:14  dario
 * problems with memmory allocation fixed.
 *
 * Revision 1.4  2005/11/17 10:11:48  dario
 * setenv added.
 *
 * Revision 1.3  2005/11/15 12:45:52  jez
 * Do not delete cValue
 *
 * Revision 1.2  2005/11/15 12:08:18  dario
 * pointers deletion added.
 *
 * Revision 1.1  2005/11/15 11:50:07  jez
 * New file.
 *
 */
#include "Common.h"
#include "NativeEnvironment.h"
#include <string.h>

#ifndef EXP_WIN32
#include <strings.h>
#endif

#include "Environment.h"

jbyteArray createJavaChars(JNIEnv*, const char*);
char* createChars(JNIEnv*, const jbyteArray);

/////////////////////////////////////////////////////////////////////////////////////////
// Gets environment variable with given name
/////////////////////////////////////////////////////////////////////////////////////////
JNIEXPORT jbyteArray JNICALL Java_com_parasoft_xtest_common_nativecode_NativeEnvironment_getenv
  (JNIEnv *env, jclass, jbyteArray name)
{
	Environment environment;
	
	const char* cname = createChars(env, name);
	if (cname) {
        const char* cvalue = environment.getenv(cname);
        delete[] cname;
        jbyteArray value = createJavaChars(env, cvalue);
#ifdef EXP_WIN32
        delete[] cvalue;
#endif
        return value;
    }
    return 0;
}

/////////////////////////////////////////////////////////////////////////////////////////
// Gets environment variables for calling process
/////////////////////////////////////////////////////////////////////////////////////////
JNIEXPORT jobjectArray JNICALL Java_com_parasoft_xtest_common_nativecode_NativeEnvironment_environment
  (JNIEnv* env, jclass)
{
	Environment environment;
	int count;

    jclass jbyteArrayClass = env->FindClass("[B");
    
	char** asEnvironment = environment.getEnvironment(count);
	if ((asEnvironment == NULL) || (count == 0)) {
	    return env->NewObjectArray(0, jbyteArrayClass, NULL);
	}

	jobjectArray result = env->NewObjectArray(count, jbyteArrayClass, NULL);
    for (int i = 0; i < count; i++) {
        jsize len = (jsize)strlen(asEnvironment[i]);
        jbyteArray value = env->NewByteArray(len);
        env->SetByteArrayRegion(value, 0, len, (jbyte*)asEnvironment[i]);
        env->SetObjectArrayElement(result, i, value);
    }
    
    // clear asEnvironment
    for (int i = 0; i < count; i++) {
        delete[] asEnvironment[i];
    }
    delete asEnvironment;
    
    return result;
 }
	
////////////////////////////////////////////////////////////////////////////////
// Set new environment variable value
////////////////////////////////////////////////////////////////////////////////
 JNIEXPORT void JNICALL Java_com_parasoft_xtest_common_nativecode_NativeEnvironment_setenv
  (JNIEnv *env, jclass, jbyteArray name, jbyteArray value)
{
	Environment environment;
	char* cname = createChars(env, name);
	char* cvalue = createChars(env, value);
	if (cname && cvalue) {
        environment.setenv(cname, cvalue);
    }
    if (cname) {
        delete[] cname;
    }
    if (cvalue) {
        delete[] cvalue;
    }
}

////////////////////////////////////////////////////////////////////////////////
// From given char array creates JNI byte array representation with buffer copy
////////////////////////////////////////////////////////////////////////////////
jbyteArray createJavaChars(JNIEnv* env, const char* str)
{
    jbyteArray jba = 0;
    if (0 != str) {
        const jsize len = (jsize)strlen(str);
        jba = env->NewByteArray(len);
        if (jba) {
            env->SetByteArrayRegion(jba, 0, len, (jbyte*)str);
        }
    }
    return jba;
}

/////////////////////////////////////////////////////////////////////////
// Helper method allocates new char array and creates copy of JNI byte 
// array representation. Client is responsible of deleting returned array
/////////////////////////////////////////////////////////////////////////
char* createChars(JNIEnv * env, const jbyteArray array)
{
    char* out = 0;
    if (array) {
        jbyte* bytes = env->GetByteArrayElements(array, 0);
        if (bytes) {
            const int len = env->GetArrayLength(array);
        
            out = new char[len + 1];
            if (out) {
                strncpy(out, (char*)bytes, len);
                out[len] = '\0';
            }
            env->ReleaseByteArrayElements(array, bytes, JNI_ABORT);
        } 
    } 
    return out;
}


