<?xml version="1.0"?>
<!-- in case of any change in xsl/xml file modify all connected xsl and xml files from this package  -->

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:graph="graph" xmlns:textutil="textutil" xmlns:results="results" xmlns:authors="authors" extension-element-prefixes="saxon">
    
    <!-- =================  print code review menu ============================ -->
    
    <xsl:template name="display_codereview_menu">
    <xsl:param name="auth"/>
    <xsl:variable name="href" saxon:assignable="yes">#cr</xsl:variable>
    <xsl:if test="$auth">
    	<saxon:assign name="href" select="concat('#cr_',$auth)"/>
    </xsl:if>
        
        <xsl:if test="($codereview) > 0">
            <xsl:call-template name="display_linked_menu_item">
            <xsl:with-param name="text" select="$RES_PARAMETER_CODEREVIEW" />
            <xsl:with-param name="link" select="$href" />
            </xsl:call-template>
        </xsl:if>  
    </xsl:template>
           
    <!-- =================  print code review ============================ -->
    
    <xsl:template name="display_codereview">
        <xsl:if test="($codereview) > 0">
            <br/>
            <xsl:call-template name="codereview_header"/>
            <br/>
            
            <xsl:call-template name="codereview_projects_summary"/>
            <br/>
            
            <xsl:if test="count(/ResultsSession/CodeReview/UndefinedAuthors/UndefinedAuthor) > 0">
                <xsl:call-template name="codereview_undefined_authors"/>
                <br/>
            </xsl:if>
            <xsl:if test="count(/ResultsSession/CodeReview/UnmatchedPaths/UnmatchedPath) > 0">
                <xsl:call-template name="codereview_unmatched_paths"/>
                <br/>
            </xsl:if>
            
            <xsl:if test="($generate_graphs = 'true') and ($cr_history) > 0">
                <br/>
                <xsl:call-template name="generate_graph">
                    <xsl:with-param name="graph" select="/ResultsSession/CodeReview/History/Graph[@id=$cr_graph_id]"/>
                    <xsl:with-param name="img_name" select="concat('cr_',$org_time)"/>
                </xsl:call-template>
            </xsl:if>
            
            <xsl:if test="($authors_details) = 'true'">
                <xsl:call-template name="codereview_authors_summary"/>
                <br/>
            </xsl:if>                        
            
            <xsl:if test="($dev_errors) = 'true'">
                <br/>
                <table width='{$width}' border='0' bordercolor='#999999' cellpadding='0' cellspacing='0'>
                    <xsl:if test="($report_format_mode='pdf')">
                        <xsl:attribute name="cols">80% 1% 19%</xsl:attribute>
                    </xsl:if>                
                    <xsl:call-template name="codereview_summary"/>
                </table>
            </xsl:if>
            
            <xsl:if test="($contexts_details) = 'true'">
                <br/>
                <xsl:call-template name="codereview_tested_files_details"/>        
            </xsl:if>
            
        </xsl:if>
    </xsl:template>
    
    <!-- =================  print codereview tested files details (1)  ============================ -->
    
    <xsl:template name="codereview_tested_files_details">
        <xsl:if test="($cr_details) > 0">
            <table width='100%' border='0' bordercolor='{$cs_bdrcolor}' cellpadding='0' cellspacing='0'>
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>               
                <tr>
                    <td>
                        <xsl:call-template name="codereview_tested_files_summary"/>
                    </td>
                </tr>
            </table>
        </xsl:if>
    </xsl:template>  
    
    
    <!-- =================  print codereview tested files summary (2) ============================ -->
    
    <xsl:template name="codereview_tested_files_summary">
        
        <xsl:variable name="expand_cr_details" select="'javascript:expandCRDetails()'"/>   
        <xsl:variable name="collapse_cr_details" select="'javascript:collapseCRDetails()'"/>   
        
        <table width='100%' border='0' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr><td  align='center'>                
                <table align='center' width="{$width}" border="0" cellpadding="0" cellspacing="0">
                    <xsl:if test="($report_format_mode='pdf')">
                        <xsl:attribute name="cols">100%</xsl:attribute>
                    </xsl:if>               
                    <tr>
                        <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
                            <td width="40%"></td>
                        </xsl:if>
                        <td width="20%" align='center'>
                            <div class="small_header"><xsl:value-of select="$RES_PARAMETER_STANDARDS_TESTED_FILES_DETAILS"/></div>
                            
                        </td>
                        <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">      
                            <td align="right" width="40%">
                                <xsl:call-template name="standard_link_ref">
                                    <xsl:with-param name="href" select="$expand_cr_details"/>
                                    <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_EXPAND_ALL"/></xsl:with-param>
                                    <xsl:with-param name="class">gray_link</xsl:with-param>
                                    <xsl:with-param name="id" select="expand_cr_details"/>
                                    <xsl:with-param name="email_class">red2</xsl:with-param>
                                </xsl:call-template>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:call-template name="standard_link_ref">
                                    <xsl:with-param name="href" select="$collapse_cr_details"/>
                                    <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_COLLAPSE_ALL"/></xsl:with-param>
                                    <xsl:with-param name="class">gray_link</xsl:with-param>
                                    <xsl:with-param name="id" select="collapse_cr_details"/>
                                    <xsl:with-param name="email_class">red2</xsl:with-param>
                                </xsl:call-template>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <xsl:call-template name="back_to_top"/>
                            </td>
                        </xsl:if> 
                    </tr>
                </table>
            </td></tr>
            <tr><td align="left">
	            <table class="doubleborder" width='{$width}' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
	            <xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">100%</xsl:attribute>
	            </xsl:if>
            	<tr><td>            
                <xsl:if test="($cr_details) > 0">                    
                    <ul class="root" id="cr_foldinglist" style="padding-left: 3px;">
                        
                        <xsl:for-each select="/ResultsSession/CodeReview/CodeReviewDetails/*">
                            <xsl:call-template name="codereview_tested_files_tree">
                                <xsl:with-param name="depth">0</xsl:with-param>
                            </xsl:call-template>
                        </xsl:for-each>
                        
                    </ul>
                </xsl:if>
	            </td></tr>
            	</table>
            </td></tr>
        </table>
    </xsl:template>
    
    <!-- =================  display codereview tree nodes (3) ============================ -->
    
    <xsl:template name="codereview_tested_files_tree">
        <xsl:param name="depth"/>               
        <xsl:variable name="isExpandable" select="boolean(not($report_type = $email_report) and ((string-length(@path) > 0) or  (count(./*) > 0)) )"/>
        
        <xsl:call-template name="codereview_details_tree_node">
            <xsl:with-param name="name" select="@name"/>
            <xsl:with-param name="issues" select="@issues"/>
            <xsl:with-param name="new" select="@new"/>
            <xsl:with-param name="rev" select="@rev"/>            
            <xsl:with-param name="depth" select="$depth"/>
            <xsl:with-param name="expandable" select="$isExpandable"/>
        </xsl:call-template>
        <ul id="cr_foldinglist">            
            <xsl:if test="($depth > 1) and not($report_type = $email_report)">
                <xsl:attribute name="style">display:none</xsl:attribute>
            </xsl:if>
            <xsl:variable name="leafExpandable" select="boolean(not($report_type = $email_report))"/>
            <xsl:variable name="li_id" saxon:assignable="yes">cr_foldheader</xsl:variable>
            <xsl:if test="not($leafExpandable)">
                <saxon:assign name="li_id">item</saxon:assign>
            </xsl:if>
            
            
            <xsl:if test="string-length(@path) > 0">
                <ul id="cr_foldinglist">
                    <li id="{$li_id}">                            
                        <xsl:variable name="path" select="@path"/>
                        <table width="89%" class="details" cellspacing="0" cellpadding='2'>
                            <xsl:if test="($report_format_mode='pdf')">
                                <xsl:attribute name="cols">60% 20% 20%</xsl:attribute>
                            </xsl:if>
                            <xsl:for-each select="/ResultsSession/Authors/Author">
                                <xsl:variable name="auth" select="@name"/>
                                
                                <xsl:variable name="label" saxon:assignable="yes"></xsl:variable>
                                <xsl:variable name="new" saxon:assignable="yes"></xsl:variable>
                                <xsl:variable name="cat_sev_label" saxon:assignable="yes"></xsl:variable>
                                <xsl:variable name="owner" saxon:assignable="yes"></xsl:variable>
                                <xsl:variable name="numOfTasks" saxon:assignable="yes">1</xsl:variable>
                                
                                <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[@path=$path and authors:compare(@owner, $auth)]">
                                    <xsl:sort select="@label"/>                                                                                                                                              
                                    <xsl:if test="count(Thr) > 0">                                        
                                       
                                        <xsl:if test="(count(Thr) = 1) and (count(Thr/ThrEl) = 1)">
                                            <xsl:if test="Thr/ThrEl/@status='Done'">
                                                <xsl:call-template name="codereview_tested_files_tree_row">
                                                    <xsl:with-param name="label" select="@label" />
                                                    <xsl:with-param name="new" select="@new" />
                                                    <xsl:with-param name="owner" select="@owner" />
                                                    <xsl:with-param name="cat_sev_label" select="concat(../../@category,'-',../../@priority)" />
                                                    <xsl:with-param name="numOfTasks" select="$numOfTasks" />
                                                </xsl:call-template>
                                            </xsl:if>
                                        </xsl:if>
                                        
                                        <xsl:for-each select="Thr">
                                            <xsl:variable name="show_file" saxon:assignable="yes">false</xsl:variable>
                                            <xsl:if test="($cat_sev_label = '')">
                                                <saxon:assign name="cat_sev_label" select="concat(@cat,'-',@sev)"/>
                                            </xsl:if>
                                                                                                                                                                               
                                            <xsl:call-template name="print_thread" >
                                                <xsl:with-param name="separator">false</xsl:with-param>                                            
                                                <xsl:with-param name="show_file">false</xsl:with-param>
                                            </xsl:call-template>                                            
                                        </xsl:for-each>
                                    </xsl:if>
                                    <xsl:if test="count(Thr) = 0">                                        
                                        <xsl:if test="not(@role='QAMANAGER')">
                                            <xsl:if test="($cat_sev_label = '')">
                                                <saxon:assign name="cat_sev_label" select="concat(../../@category,'-',../../@priority)"/>                                                                                            
                                            </xsl:if>
                                            <xsl:choose>
                                                <xsl:when test="($label = '')">
                                                    <saxon:assign name="label" select="@label"/>                                            
                                                    <saxon:assign name="new" select="@new"/>
                                                    <saxon:assign name="owner" select="@owner"/>
                                                </xsl:when>
                                                <xsl:when test="($label = @label) and ($new = @new)">
                                                    <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
                                                </xsl:when>
                                                <xsl:otherwise>                                                                                                                                                                             
                                                    <xsl:call-template name="codereview_tested_files_tree_row">
                                                        <xsl:with-param name="label" select="$label" />
                                                        <xsl:with-param name="new" select="$new" />
                                                        <xsl:with-param name="owner" select="$owner" />
                                                        <xsl:with-param name="cat_sev_label" select="$cat_sev_label" />
                                                        <xsl:with-param name="numOfTasks" select="$numOfTasks" />
                                                    </xsl:call-template>
                                                    <saxon:assign name="numOfTasks" select="1"/>
                                                    <saxon:assign name="label" select="@label"/>
                                                    <saxon:assign name="owner" select="@owner"/>
                                                </xsl:otherwise>                                        
                                            </xsl:choose>
                                        </xsl:if>
                                    </xsl:if>
                                </xsl:for-each>
                                <xsl:if test="not($label='')">
                                    <xsl:call-template name="codereview_tested_files_tree_row">
                                        <xsl:with-param name="label" select="$label" />
                                        <xsl:with-param name="new" select="$new" />
                                        <xsl:with-param name="owner" select="$owner" />
                                        <xsl:with-param name="cat_sev_label" select="$cat_sev_label" />
                                        <xsl:with-param name="numOfTasks" select="$numOfTasks" />
                                    </xsl:call-template>
                                </xsl:if>
                            </xsl:for-each>
                        </table>
                    </li>
                </ul>	
            </xsl:if> 
            
            
            <xsl:for-each select="./*">
                <xsl:sort select="@name"/>                
                <xsl:call-template name="codereview_tested_files_tree">
                    <xsl:with-param name="depth" select="$depth + 1"/>
                </xsl:call-template>
            </xsl:for-each>
        </ul>		
    </xsl:template>
    
    <!-- =================  codereview_tested_files_tree_row  ============================ -->
    
    <xsl:template name="codereview_tested_files_tree_row">
        <xsl:param name="label"></xsl:param>
        <xsl:param name="new"></xsl:param>
        <xsl:param name="owner"></xsl:param>
        <xsl:param name="cat_sev_label"></xsl:param>        
        <xsl:param name="numOfTasks"></xsl:param>
        <tr>
            <td><xsl:value-of select="$label"/>                                            
                <xsl:if test="$new='true'">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>(new)                                        
                </xsl:if>                
                <xsl:if test="($numOfTasks &gt; 1)">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    [<xsl:value-of select="($numOfTasks)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:value-of select="$RES_PARAMETER_TASKS_LOWERCASE"/>]
                </xsl:if>
            </td>
            <td class="fixed_width" align="left" ><xsl:value-of select="$owner"/>                                                                                   
            </td>                                                        
            <td class="fixed_width" align="right">
                <font class="gray"><xsl:value-of select="$cat_sev_label"/></font>
            </td>
        </tr>
    </xsl:template>
    
    <!-- =================  print codereview details tree node (4) ============================ -->
    
    <xsl:template name="codereview_details_tree_node">
        <xsl:param name="name"/>
        <xsl:param name="issues"/>
        <xsl:param name="new"/>
        <xsl:param name="rev"/>
        <xsl:param name="depth"/>
        <xsl:param name="expandable"/>               
        
        <xsl:variable name="li_id" saxon:assignable="yes">cr_foldheader</xsl:variable>
        <xsl:if test="not($expandable)">
            <saxon:assign name="li_id">item</saxon:assign>
        </xsl:if>
        
        <xsl:variable name="font_color" saxon:assignable="yes" select="$green_color"/>
        <xsl:if test="(issues > 0)">
            <saxon:assign name="font_color" select ="$red_color"/>
        </xsl:if>
        
        <li id="{$li_id}">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:if test="$expandable = 'true'">
                <font color="{$cs_bcolor}">+</font>
            </xsl:if>
            <xsl:if test="not($expandable = 'true')">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>[<b><xsl:value-of
                select="($new)"/></b>/<b><xsl:value-of select="$rev"/></b>/<b><xsl:value-of select="$issues"/></b>]                
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <b><xsl:value-of select="($name)"/></b>	
        </li>    
        
    </xsl:template>
    
    
    <!-- =================  print codereview summary  ============================ -->
    
    <xsl:template name="codereview_summary">
        <xsl:for-each select="/ResultsSession/Authors/Author">            
            <xsl:call-template name="codereview_summary_details">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
                <xsl:with-param name="mode">summary</xsl:with-param>
            </xsl:call-template>            
        </xsl:for-each> 
    </xsl:template>  
    
    <!-- =================  print codereview summary details ===================== -->
    
    <xsl:template name="codereview_summary_details">
        <xsl:param name="auth"/>
        <xsl:param name="authid"/>
        <xsl:param name="mode"/>
        <xsl:variable name="totErrs" select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='true'])"/>                
        <xsl:if test="$totErrs > 0 ">
            <tr>
            	<td style="padding-left:20px;" align="left" nowrap="nowrap" colspan="2">
			    <b><xsl:value-of select="($auth)"/></b>
			    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
			    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>	    	    			    
                <xsl:value-of select="$RES_PARAMETER_PENDING_ISSUES" />	                
			    
			    :<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($totErrs)"/>
			    </td>
			    <td style="padding-right:20px;" align="right" nowrap="true">
 	  	            <xsl:if test="not($report_type = $email_report)">
                       <xsl:call-template name="back_to_top"/>
                    </xsl:if>
			    </td>	             
            </tr>
            <tr>
            <td colspan="3" align="center">    
			<table class="doubleborder" bordercolor="{$cr_bdrcolor}" aligh="center" width="100%" rules="none">
			<xsl:if test="($report_format_mode='pdf')">
                        <xsl:attribute name="cols">80% 1% 19%</xsl:attribute>
                    </xsl:if>   
	            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='true']/Thr">                
	                <xsl:call-template name="print_thread" >
	                    <xsl:with-param name="separator">true</xsl:with-param>    
	                    <xsl:with-param name="show_file">true</xsl:with-param>
	                </xsl:call-template>                 
	            </xsl:for-each>
            </table>            
            </td>
            </tr>
        </xsl:if>
    </xsl:template>        
    
   <xsl:template name="print_thread">
        <xsl:param name="separator"></xsl:param>
        <xsl:param name="show_file"></xsl:param>
        
        <xsl:if test="$show_file='true'">
            <tr>
                <td style="padding-left:10px"><b><xsl:value-of select="../@path"/></b>
                    <xsl:variable name="rev" select="@rev"/>
                    <xsl:if test="(string-length($rev) > 0) and not($rev = 'unknown.revision')">
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <font class="gray"><xsl:value-of select="$RES_PARAMETER_REVISION"/></font>
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <font class="gray"><xsl:value-of select="($rev)"/></font>
                    </xsl:if>            
                </td>
                <xsl:if test="($report_format_mode='pdf')">
                    <td align="left"></td>
                    <td align="right"><font class="gray"><xsl:value-of select="@cat"/>-<xsl:value-of select="@sev"/></font></td>
                </xsl:if> 
                <xsl:if test="not ($report_format_mode='pdf')">
                    <td class="fixed_width"  align="left"></td>
                    <td style="padding-right:10px" class="fixed_width"  align="right"><font class="gray"><xsl:value-of select="@cat"/>-<xsl:value-of select="@sev"/></font></td>
                </xsl:if>
            </tr>
        </xsl:if>
        <xsl:for-each select="ThrEl">                                                       
            <tr>
                <xsl:if test="$show_file='true'">
                    <td style="padding-left:10px;padding-right:10px" colspan="3"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="@status"/> from <b><xsl:value-of select="@user"/></b> (<xsl:value-of select="textutil:lowercase(@role)"/>) at <xsl:value-of select="@date"/></td>
                </xsl:if>
                <xsl:if test="not ($show_file='true')">
                    <td style="padding-left:10px"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="@status"/> from <b><xsl:value-of select="@user"/></b> (<xsl:value-of select="textutil:lowercase(@role)"/>) at <xsl:value-of select="@date"/></td>               
                    <td class="fixed_width"  align="right"></td>
                    <td style="padding-right:10px" class="fixed_width"  align="right"><font class="gray"><xsl:value-of select="../@cat"/>-<xsl:value-of select="../@sev"/></font></td>
                </xsl:if>                
            </tr>
            <xsl:if test="string-length(Comment/text()) > 0">
                <tr>
                    <td colspan="3">
                        <div style="margin: 10px 0px 10px 20px;">
                            <pre style="padding: 5px; font-style: italic;"><xsl:value-of select="Comment/text()"/></pre>
                        </div></td>                     
                </tr>     
            </xsl:if>
            <xsl:if test="not (string-length(Comment/text()) > 0)">
                <tr>
                    <td colspan="3"><br/></td>
                </tr>
            </xsl:if>
        </xsl:for-each>        
    </xsl:template>
    
    <!-- =================  print code review header ============================ -->
    
    <xsl:template name="codereview_header">
        <xsl:param name="ref"/>
        <xsl:if test="not(string-length($ref) > 0)">
            <a name="cr"/>
        </xsl:if>
        <xsl:if test="string-length($ref) > 0">
            <a name="{$ref}"/>
        </xsl:if>
        <table  width='{$width}' border='0' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">15% 70% 15%</xsl:attribute>
            </xsl:if>
            <tr>
                <td width="15%"></td>
                <td align="center">                    
                    <div class="header"><xsl:value-of select="$RES_PARAMETER_CODEREVIEW"/></div>
                </td>
                <td width="15%" align="right" valign="bottom">
	  	           <xsl:if test="not($report_type = $email_report) and ($first_back_to_top = 'false')">
                      <xsl:call-template name="back_to_top"/>
                   </xsl:if>
   		           <saxon:assign name="first_back_to_top">false</saxon:assign>
                </td>
            </tr>
        </table>
        
    </xsl:template>
    
    <!-- =================  codereview_projects_summary ============================ -->
    
    <xsl:template name="codereview_projects_summary">
        <table class="singleborder" width='{$width}' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">55% 15% 15% 15%</xsl:attribute>
            </xsl:if>
            <xsl:call-template name="projects_summary_table_header" />
            <xsl:call-template name="codereview_project_list"/>
        </table>
    </xsl:template> 
    
    <!-- =================  projects summary table header ================================== -->
    
    <xsl:template name="projects_summary_table_header">       
        <tr bgcolor="{$cr_bcolor}">
            <td class="singleborder" width="50%" align="center" rowspan="2">
                <b><xsl:value-of select="$RES_PARAMETER_PROJECT_NAME"/></b><br/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>
            <td class="singleborder" colspan="3" align='center'>
                <b><xsl:value-of select="$RES_PARAMETER_TASKS"/></b>
            </td>
        </tr>
        <tr bgcolor="{$cr_bcolor}">            
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_NEW"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_PENDING_REVIEWS"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_PENDING_ISSUES"/>
            </td>
        </tr>
    </xsl:template>
    
    <!-- =================  summary table header ================================== -->
    
    <xsl:template name="summary_table_header">        
        <tr bgcolor="{$cr_bcolor}">
            <td class="singleborder" width="50%" align="center" rowspan="2">
                <b><xsl:value-of select="$RES_PARAMETER_AUTHOR"/></b><br/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>
            <td class="singleborder" colspan="5" align='center'>
                <b><xsl:value-of select="$RES_PARAMETER_TASKS"/></b>
            </td>
        </tr>
        <tr bgcolor="{$cr_bcolor}">
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_CREATED"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_NEW"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_PENDING_REVIEWS"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_PENDING_ISSUES"/>
            </td>
            <td class="singleborder" align='center' width='10%'>
                <xsl:value-of select="$RES_PARAMETER_CR_MONITORED"/>
            </td>
        </tr>
    </xsl:template>
    <!-- =================  codereview_authors_summary ============================ -->
    
    <xsl:template name="codereview_authors_summary">
        <xsl:call-template name="authors_header" />
        <table align="center" class="singleborder" width='{$authors_width}' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">50% 10% 10% 10% 10% 10%</xsl:attribute>
            </xsl:if>
            <xsl:call-template name="summary_table_header" />
            <xsl:call-template name="codereview_author_list"/>
        </table>
    </xsl:template> 
    
    <!-- =================  codereview_undefined_authors ============================ -->
    
    <xsl:template name="codereview_undefined_authors">
        <table class="doubleborder" width='{$width}' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr bgcolor="{$cr_bcolor}">
                <td width="100%" align="center">
                    <b><xsl:value-of select="$RES_PARAMETER_UNDEFINED_AUTHORS"/></b>
                </td>
            </tr>
            
            <xsl:variable name="first" saxon:assignable="yes">true</xsl:variable>
            <tr><td width="100%" align='left'>
                <xsl:for-each select="/ResultsSession/CodeReview/UndefinedAuthors/UndefinedAuthor">
                    <xsl:if test="($first = 'false')">,</xsl:if>
                    <xsl:value-of select="' '" disable-output-escaping="yes"/><xsl:value-of select="@name"/>
                    <saxon:assign name="first">false</saxon:assign>
                </xsl:for-each>
            </td></tr>
            
        </table>
    </xsl:template>     
    
    <!-- =================  codereview_unmatched_paths ============================ -->
    
    <xsl:template name="codereview_unmatched_paths">
        <table width='{$width}' border='1' bordercolor='{$cr_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr bgcolor="{$cr_bcolor}">
                <td width="100%" align="center">
                    <b><xsl:value-of select="$RES_PARAMETER_UNMATCHED_PATHS"/></b>
                </td>
            </tr>
            
            <xsl:variable name="firstName" saxon:assignable="yes">true</xsl:variable>
            <xsl:variable name="currentName" saxon:assignable="yes"></xsl:variable>
            <tr><td width="100%" align='left'>
                <xsl:for-each select="/ResultsSession/CodeReview/UnmatchedPaths//UnmatchedPath[@name]">
                    <xsl:sort select="@name"/>
                    
                    <xsl:if test="(@name != $currentName)">
                        <saxon:assign name="currentName">
                            <xsl:value-of select="@name"/>
                        </saxon:assign>
                        
                        <xsl:if test="($firstName = 'false')">
                            <br />
                        </xsl:if>
                        
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <xsl:value-of select="@name"/>:
                        
                        <xsl:variable name="firstPath" saxon:assignable="yes">true</xsl:variable>          
                        <xsl:for-each select="/ResultsSession/CodeReview/UnmatchedPaths//UnmatchedPath[@name=($currentName)]">
                            <xsl:sort select="@path"/>
                            <xsl:if test="($firstPath = 'false')">,
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                            </xsl:if>
                            <xsl:value-of select="@path"/>
                            
                            <saxon:assign name="firstPath">false</saxon:assign>
                        </xsl:for-each>
                    </xsl:if>
                    
                    <saxon:assign name="firstName">false</saxon:assign>
                </xsl:for-each>
            </td></tr>
            
        </table>
    </xsl:template>     
    
    <!-- =================  print code review auth list ============================ -->
    
    <xsl:template name="codereview_author_list">
        <xsl:for-each select="/ResultsSession/Authors/Author[not (authors:compare(@name, preceding-sibling::node()/@name))]">
            <xsl:variable name="auth" select="@name"/>
            <xsl:variable name="active_user_cr_created_tasks" 
                select="count(/ResultsSession/CodeReview/ScannerReviews/Review/CreatedTasks/Task[authors:compare(@owner, $auth) and @new='true' and @active='true'])"/>
            <xsl:variable name="active_user_cr_pending_tasks" 
                select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @active='true'])"/>
            <xsl:variable name="active_user_cr_monitor_tasks" 
                select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and @role='QAMANAGER' and @active='true'])"/>
            
            <xsl:if test="$active_user_cr_created_tasks or $active_user_cr_pending_tasks or $active_user_cr_monitor_tasks">
                <xsl:call-template name="codereview_author_info">
                    <xsl:with-param name="auth" select="($auth)"/>
                    <xsl:with-param name="authid" select="@id"/>
                </xsl:call-template>
            </xsl:if>
            
        </xsl:for-each>  
    </xsl:template> 
    
    <!-- =================  print code review project list ============================ -->
    
    <xsl:template name="codereview_project_list">
        
        <xsl:for-each select="/ResultsSession/CodeReview/CodeReviewDetails/Total/Project">
            <xsl:sort select="@name"/>
                
            <tr>
                <td class="singleborder" align="left">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>                    
                    <xsl:value-of select="(@name)"/>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>   
                
                <td class="singleborder" align="right">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:value-of select="(@new)"/>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>
                
                <td class="singleborder" align="right">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:value-of select="(@rev)"/>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>   
                
                <td class="singleborder" align="right">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:value-of select="(@issues)"/>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>                 
            </tr>            
            
        </xsl:for-each>  
    </xsl:template>
    
    <!-- =================  print code review auth info ============================ -->
    
    <xsl:template name="codereview_author_info">
        <xsl:param name="auth"/>
        <xsl:param name="authid"/>
        
        <xsl:variable name="user_created_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/CreatedTasks/Task[authors:compare(@owner, $auth) and @new='true'])"/>
        <xsl:variable name="user_new_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @new='true'])"/>
        <xsl:variable name="user_pending_reviews" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='false'])"/>
        <xsl:variable name="user_pending_issues" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='true'])"/>
        <xsl:variable name="user_monitor_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and @role='QAMANAGER'])"/>
        
        <xsl:variable name="link_class" saxon:assignable="yes">blue_link</xsl:variable>
        <xsl:variable name="font_class" saxon:assignable="yes">blue</xsl:variable>
        
        <xsl:variable name="author_all_tasks" select="($user_created_tasks) + ($user_new_tasks) + ($user_pending_reviews) + ($user_pending_issues) + ($user_monitor_tasks)"/>
        
        <xsl:if test="($author_all_tasks = 0)">
            <saxon:assign name="font_class">green</saxon:assign>
        </xsl:if>
        <tr>
            <td class="singleborder" align="left">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:if test="($report_type) = ($tcm_report)">
	                <xsl:if test="($author_all_tasks) > 0">
	                    
	                    <xsl:if test="($dev_reports = 'true')">     
	                        <xsl:variable name="dev_rep_name" select="concat($dev_reports_prefix,$authid,'.html')"/>
	                        <xsl:variable name="href" select="concat('javascript:openDevReport(',$qt,$dev_rep_name,$qt,')')"/>                               
	                        <xsl:call-template name="standard_link_ref">
	                            <xsl:with-param name="href" select="($href)"/>
	                            <xsl:with-param name="label" select="($auth)"/>
	                            <xsl:with-param name="class" select="($link_class)"/>
	                        </xsl:call-template>
	                    </xsl:if>
	                    
	                    <xsl:if test="(($dev_errors) = 'true') and ($dev_reports = 'false')">    
	                        <a class="{$link_class}" href="#cr_{$authid}">
	                            <xsl:value-of select="($auth)"/>
	                        </a>
	                    </xsl:if>
	                    
	                    <xsl:if test="(($dev_errors) = 'false') and ($dev_reports = 'false')">
	                        <font class="{$font_class}">
	                            <xsl:value-of select="($auth)"/>
	                        </font>
	                    </xsl:if>   
	                    
	                </xsl:if>
	                
	                <xsl:if test="not(($author_all_tasks) > 0)">
	                    <font class="{$font_class}">
	                        <xsl:value-of select="($auth)"/>
	                    </font>
	                </xsl:if>
                </xsl:if>
                <xsl:if test="($report_type) = ($email_report)">
	                <xsl:if test="($user_pending_issues) > 0">	                    	                    	                  
	                    <xsl:if test="($dev_errors) = 'true'">    
	                        <a class="{$link_class}" href="#cr_{$authid}">
	                            <xsl:value-of select="($auth)"/>
	                        </a>
	                    </xsl:if>
	                    
	                    <xsl:if test="($dev_errors) = 'false'">
	                        <font class="{$font_class}">
	                            <xsl:value-of select="($auth)"/>
	                        </font>
	                    </xsl:if>   
	                    
	                </xsl:if>
	                <xsl:if test="not(($user_pending_issues) > 0)">
	                    <font class="{$font_class}">
	                        <xsl:value-of select="($auth)"/>
	                    </font>
	                </xsl:if>
                </xsl:if>
                
                <xsl:if test="($report_type) = ($disk_report)">
	                <xsl:if test="($author_all_tasks) > 0">	                    
	                    <xsl:if test="($dev_reports) = 'true'">     
	                        <xsl:variable name="author_html" select="concat($dev_reports_prefix,$authid,'.html#cr_',$authid)"/>
	                        <xsl:variable name="href" saxon:assignable="yes" select="concat('javascript:openWin(',$qt,$author_html,$qt,')')"/>
	                        <xsl:call-template name="standard_link_ref">
	                            <xsl:with-param name="href" select="($href)"/>
	                            <xsl:with-param name="label" select="($auth)"/>
	                            <xsl:with-param name="class" select="($link_class)"/>
	                        </xsl:call-template>
	                    </xsl:if>	                       	                 
	                </xsl:if>
	                
	                <xsl:if test="not(($author_all_tasks) > 0)">
	                    <font class="{$font_class}">
	                        <xsl:value-of select="($auth)"/>
	                    </font>
	                </xsl:if>
                </xsl:if>                                              
                
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
            
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($user_created_tasks)"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>
            
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($user_new_tasks)"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
            
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($user_pending_reviews)"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
            
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($user_pending_issues)"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
            
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($user_monitor_tasks)"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>
            
        </tr>
    </xsl:template> 
    
    <!-- =================  codereview author details info ============================ -->
    
    <xsl:template name="codereview_author_details_info">
        <xsl:param name="auth"/>    
        <xsl:param name="authid"/>
        
        <xsl:variable name="user_created_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/CreatedTasks/Task[authors:compare(@owner, $auth) and @new='true'])"/>
        <xsl:variable name="user_new_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @new='true'])"/>
        <xsl:variable name="user_pending_reviews" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='false'])"/>
        <xsl:variable name="user_pending_issues" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='true'])"/>
        <xsl:variable name="user_monitor_tasks" 
            select="count(/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and @role='QAMANAGER'])"/>
        
        
        <xsl:variable name="author_cr_history" select="count(/ResultsSession/CodeReview/History/Graph[@id=$cr_graph_id]/Authors/Author[authors:compare(@name, $auth)]/X)"/>        
        <xsl:if test="($generate_graphs = 'true') and ($author_cr_history) > 0">
            <xsl:call-template name="generate_graph">
                <xsl:with-param name="graph" select="/ResultsSession/CodeReview/History/Graph[@id=$cr_graph_id]"/>
                <xsl:with-param name="img_name" select="concat('cr_',$authid,'_',$org_time)"/>
                <xsl:with-param name="auth" select="$auth"/>
            </xsl:call-template>
            <br/>
        </xsl:if>
        
        <table width="{$width}" cellpadding="0" cellspacing="0" border="0">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
            </xsl:if>
            
            <tr>						  
		    	<xsl:call-template name="details_table_auth_header">
		    		<xsl:with-param name="auth" select="$auth"/>
		    		<xsl:with-param name="number" select="$user_created_tasks"/>
		    		<xsl:with-param name="message" select="$RES_PARAMETER_CREATED_REVIEWS"/>
		    		<xsl:with-param name="anchor" select="concat('cr_created_',$auth)"/>    		    		
		   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
		    </tr>
         	
            <xsl:variable name="label" saxon:assignable="yes"></xsl:variable>
            <xsl:variable name="numOfTasks" saxon:assignable="yes">1</xsl:variable>
            
            <xsl:if test="$user_created_tasks &gt; 0">
	    <tr>
            	<td colspan="3" align="center">
   				<table aligh="center" width="100%" bgcolor="#FFFFFF" class="doubleborder" bordercolor="{$cs_bdrcolor}" rules="none" cellpadding="0" cellspacing="0">
   				<xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
	            </xsl:if>
   				   
            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/CreatedTasks/Task[authors:compare(@owner, $auth) and @new='true']">
                <xsl:sort select="@label"/>
                <xsl:choose>
                    <xsl:when test="($label = '')">
                        <saxon:assign name="label" select="@label"/>
                        
                    </xsl:when>
                    <xsl:when test="($label = @label)">
                        <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="codereview_author_details_info_row">
                            <xsl:with-param name="label" select="($label)"/>
                            <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                        </xsl:call-template>
                        
                        <saxon:assign name="numOfTasks" select="1"/>
                        <saxon:assign name="label" select="@label"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:if test="not($label='')">
                <xsl:call-template name="codereview_author_details_info_row">
                    <xsl:with-param name="label" select="($label)"/>
                    <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                </xsl:call-template>
            </xsl:if>
            
			</table>
				</td>
            </tr>
            </xsl:if>
            <tr>
                <td colspan="3"><br/></td>
            </tr>
                   
		    <tr>     				   		    
		    	<xsl:call-template name="details_table_auth_header">
		    		<xsl:with-param name="auth" select="$auth"/>
		    		<xsl:with-param name="anchor" select="concat('cr_new_',$auth)"/>
		    		<xsl:with-param name="number" select="$user_new_tasks"/>
		    		<xsl:with-param name="message" select="$RES_PARAMETER_NEW_REVIEWS"/>    		    		
		   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
		    </tr>	              
            
            <xsl:if test="$user_new_tasks &gt; 0">
	    <tr>
            	<td colspan="3" align="center">
   				<table aligh="center" width="100%" bgcolor="#FFFFFF" class="doubleborder" bordercolor="{$cs_bdrcolor}" rules="none" cellpadding="0" cellspacing="0">
	   				<xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
	            </xsl:if>
   				
            <saxon:assign name="label" select="''"/>
            <saxon:assign name="numOfTasks" select="1"/>
            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @new='true']">
                <xsl:sort select="@label"/>
                <xsl:choose>
                    <xsl:when test="($label = '')">
                        <saxon:assign name="label" select="@label"/>
                        
                    </xsl:when>
                    <xsl:when test="($label = @label)">
                        <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
                        
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="codereview_author_details_info_row">
                            <xsl:with-param name="label" select="($label)"/>
                            <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                        </xsl:call-template>
                        
                        <saxon:assign name="numOfTasks" select="1"/>
                        <saxon:assign name="label" select="@label"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:if test="not($label='')">
                <xsl:call-template name="codereview_author_details_info_row">
                    <xsl:with-param name="label" select="($label)"/>
                    <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                </xsl:call-template>
            </xsl:if>
            
            </table>
				</td>
            </tr>
            </xsl:if>
            <tr>
                <td colspan="3"><br/></td>
            </tr>    
            
            <!-- Pending reviews -->
            
            <tr>     				   
		    	<xsl:call-template name="details_table_auth_header">
		    		<xsl:with-param name="anchor" select="concat('cr_pending_revs_',$auth)"/>
		    		<xsl:with-param name="auth" select="$auth"/>
		    		<xsl:with-param name="number" select="$user_pending_reviews"/>
		    		<xsl:with-param name="message" select="$RES_PARAMETER_PENDING_REVIEWS"/>    		    		
		   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
		    </tr>		               
            
            <xsl:if test="$user_pending_reviews &gt; 0">
            <tr>
            	<td colspan="3" align="center">
   				<table aligh="center" width="100%" bgcolor="#FFFFFF" class="doubleborder" bordercolor="{$cs_bdrcolor}" rules="none" cellpadding="0" cellspacing="0">
   				<xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
	            </xsl:if>
   				
            <saxon:assign name="label" select="''"/>
            <saxon:assign name="numOfTasks" select="1"/>
            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='false']">
                <xsl:sort select="@label"/>
                <xsl:choose>
                    <xsl:when test="($label = '')">
                        <saxon:assign name="label" select="@label"/>
                        
                    </xsl:when>
                    <xsl:when test="($label = @label)">
                        <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
                        
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="codereview_author_details_info_row">
                            <xsl:with-param name="label" select="($label)"/>
                            <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                        </xsl:call-template>
                        
                        <saxon:assign name="numOfTasks" select="1"/>
                        <saxon:assign name="label" select="@label"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:if test="not($label='')">
                <xsl:call-template name="codereview_author_details_info_row">
                    <xsl:with-param name="label" select="($label)"/>
                    <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                </xsl:call-template>
            </xsl:if>
            
            </table>
				</td>
            </tr>
            </xsl:if>
            <tr>
                <td colspan="3"><br/></td>
            </tr>
            
            <!-- Pending issues -->
            
            <tr>     				   
		    	<xsl:call-template name="details_table_auth_header">
		    		<xsl:with-param name="anchor" select="concat('cr_pending_issues_',$auth)"/>
		    		<xsl:with-param name="auth" select="$auth"/>
		    		<xsl:with-param name="number" select="$user_pending_issues"/>
		    		<xsl:with-param name="message" select="$RES_PARAMETER_PENDING_ISSUES"/>    		    		
		   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
		    </tr>
		      
            <xsl:if test="$user_pending_issues &gt; 0">
		      <tr>
            	<td colspan="3" align="center">
   				<table aligh="center" width="100%" bgcolor="#FFFFFF" class="doubleborder" bordercolor="{$cs_bdrcolor}" rules="none" cellpadding="0" cellspacing="0">
   				<xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
	            </xsl:if>                     
            <saxon:assign name="label" select="''"/>
            <saxon:assign name="numOfTasks" select="1"/>
            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and (@role='REVIEWER' or @role='OWNER') and @issue='true']">
                <xsl:sort select="@label"/>
                <xsl:choose>
                    <xsl:when test="($label = '')">
                        <saxon:assign name="label" select="@label"/>
                        
                    </xsl:when>
                    <xsl:when test="($label = @label)">
                        <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
                        
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="codereview_author_details_info_row">
                            <xsl:with-param name="label" select="($label)"/>
                            <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                        </xsl:call-template>
                        
                        <saxon:assign name="numOfTasks" select="1"/>
                        <saxon:assign name="label" select="@label"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:if test="not($label='')">
                <xsl:call-template name="codereview_author_details_info_row">
                    <xsl:with-param name="label" select="($label)"/>
                    <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
                </xsl:call-template>
            </xsl:if>
            </table>
				</td>
            </tr>
            </xsl:if>
            <tr>
                <td colspan="3"><br/></td>
            </tr>
            
            <!-- Monitor tasks -->
            <tr>     				   
		    	<xsl:call-template name="details_table_auth_header">
		    		<xsl:with-param name="anchor" select="concat('cr_monitored_',$auth)"/>
		    		<xsl:with-param name="auth" select="$auth"/>
		    		<xsl:with-param name="number" select="$user_monitor_tasks"/>
		    		<xsl:with-param name="message" select="$RES_PARAMETER_MONITOR_REVIEWS"/>    		    		
		   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
		    </tr>
		               
            <xsl:if test="$user_monitor_tasks &gt; 0">
            <tr>
            	<td colspan="3" align="center">
   				<table aligh="center" width="100%" bgcolor="#FFFFFF" class="doubleborder" bordercolor="{$cs_bdrcolor}" rules="none" cellpadding="0" cellspacing="0">
   				<xsl:if test="($report_format_mode='pdf')">
	                <xsl:attribute name="cols">33% 33% 34%</xsl:attribute>
	            </xsl:if>
   				                
            <saxon:assign name="label" select="''"/>
            <saxon:assign name="numOfTasks" select="1"/>
            
	            <xsl:for-each select="/ResultsSession/CodeReview/ScannerReviews/Review/Tasks/Task[authors:compare(@owner, $auth) and @role='QAMANAGER']">
	                <xsl:sort select="@label"/>
	                <xsl:choose>
	                    <xsl:when test="($label = '')">
	                        <saxon:assign name="label" select="@label"/>
	                        
	                    </xsl:when>
	                    <xsl:when test="($label = @label)">
	                        <saxon:assign name="numOfTasks" select="$numOfTasks + 1"/>
	                        
	                    </xsl:when>
	                    <xsl:otherwise>
	                        <xsl:call-template name="codereview_author_details_info_row">
	                            <xsl:with-param name="label" select="($label)"/>
	                            <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
	                        </xsl:call-template>
	                        
	                        <saxon:assign name="numOfTasks" select="1"/>
	                        <saxon:assign name="label" select="@label"/>
	                    </xsl:otherwise>
	                </xsl:choose>
	            </xsl:for-each>
	            <xsl:if test="not($label='')">
	                <xsl:call-template name="codereview_author_details_info_row">
	                    <xsl:with-param name="label" select="($label)"/>
	                    <xsl:with-param name="numOfTasks" select="($numOfTasks)"/>
	                </xsl:call-template>
	            </xsl:if>
                </table>
				</td>
            </tr>
            </xsl:if>

            <tr>
                <td colspan="3"><br/></td>
            </tr>
            
            <xsl:call-template name="codereview_summary_details">
                <xsl:with-param name="auth" select='($auth)'/>
                <xsl:with-param name="authid" select='($authid)'/>
                <xsl:with-param name="mode"></xsl:with-param>
            </xsl:call-template>
            
        </table>
        
        
        
    </xsl:template>
    
    <xsl:template name="codereview_author_details_info_row">
        <xsl:param name="label"/>
        <xsl:param name="numOfTasks"/>
        <tr>
            <td style="padding-left:10px">
                <xsl:value-of select="($label)"/>
            </td>
            <td></td>
            <xsl:call-template name="num_of_tasks">
                <xsl:with-param name="numOfTasks" select="$numOfTasks" />
            </xsl:call-template>
        </tr>
    </xsl:template>
    
    
    <xsl:template name="num_of_tasks">
        <xsl:param name="numOfTasks"/>
        <td style="padding-right:10px" class="fixed_width" align="right">
            <xsl:value-of select="($numOfTasks)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:if test="($numOfTasks = 1)">
                <xsl:value-of select="$RES_PARAMETER_TASK_LOWERCASE"/>
            </xsl:if>
            <xsl:if test="not($numOfTasks = 1)">
                <xsl:value-of select="$RES_PARAMETER_TASKS_LOWERCASE"/>
            </xsl:if>
        </td>
    </xsl:template>
    
    
</xsl:stylesheet>
